package org.ow2.weblab.rdf;

/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2010 CASSIDIAN
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 * 
 * /!\ At the time of the 1.2 release, this module is still experimental and need more in 
 * depth use and validation. Use it at your own risks ;-)
 */

import java.net.URI;
import java.util.List;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.stream.XMLOutputFactory;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamWriter;
import javax.xml.transform.dom.DOMResult;

import org.apache.commons.logging.LogFactory;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.w3c.dom.Document;
import org.w3c.dom.Node;

public class RDFWriter implements CommonNamespaces {

	private RDFWriter(){
		throw new UnsupportedOperationException("This class only contains " + "static methods; no need to instantiate it.");
	}
	
	protected static XMLOutputFactory outputFactory = null;
	protected static String XML_PARSER_CLASS = "com.sun.xml.internal.stream.XMLOutputFactoryImpl";

	public static void writeStatement(PieceOfKnowledge annotation, URI subject, String prefix, URI namespace, String property, Object value, String lang, boolean add) throws Exception {
		Object o = annotation.getData();
		if (o == null) {
			createAnnotation(annotation, subject, prefix, namespace.toString(), property, value, lang);
		} else {
			updateAnnotation(annotation, subject, prefix, namespace.toString(), property, value, lang, add);
		}
	}

	private static void updateAnnotation(PieceOfKnowledge annotation, URI subject, String prefix, String namespace, String property, Object value, String lang, boolean add) throws XMLStreamException {
		Node n = (Node) annotation.getData();

		// We search for an rdf description about the subject
		Node description = RDFReader.findDescriptionAbout(n, subject.toString());

		if (description == null) {
			// we create a new description node
			description = createDescriptionAbout(RDFReader.findRDF(n), subject.toString());
			if (description == null) {
				throw new XMLStreamException("Can not create rdf:description about : " + subject);
			}
		} else if (!add) {
			List<Node> nodes = RDFReader.findNodesWithProperty(description, namespace, property);

			for (Node node : nodes) {
				if (lang != null) {
					String nlang = RDFReader.getLanguage(node);
					if (lang.equalsIgnoreCase(nlang)) {
						node.getParentNode().removeChild(node);
					}
				} else {
					node.getParentNode().removeChild(node);
				}
			}

		}

		DOMResult domResult = new DOMResult(description);

		XMLStreamWriter xmlw = createXMLStreamWriter(domResult);
		writeAnnotation(xmlw, prefix, namespace, property, value, lang);
		xmlw.close();
		annotation.setData(n);

	}

	private static XMLStreamWriter createXMLStreamWriter(DOMResult domResult) throws XMLStreamException {
		if (outputFactory == null) {
			try {
				/**
				 * Try to prevent XML API overriding.
				 * Sun XML parser is valid with namespace and xml:lang support in XML.
				 */
				Class<?> clazz = ClassLoader.getSystemClassLoader().loadClass(XML_PARSER_CLASS);
				outputFactory = (XMLOutputFactory) clazz.newInstance();
			} catch (ClassNotFoundException e) {
				LogFactory.getLog(RDFWriter.class).warn(e);
			} catch (InstantiationException e) {
				LogFactory.getLog(RDFWriter.class).warn(e);
			} catch (IllegalAccessException e) {
				LogFactory.getLog(RDFWriter.class).warn(e);
			}
			if (outputFactory == null) {
				LogFactory.getLog(RDFWriter.class).warn(
						"Your JVM is not the Sun one, this is not really a problem " + "(we like open source too) but please define an implementation "
								+ "of a XMLOutputFactory in META-INF/services/javax.xml.stream.XMLOutputFactory");
				/**
				 * Your JVM is not the Sun one, this is not really a problem (we like open source too) but
				 * please define an implementation of a XMLOutputFactory in META-INF/services/javax.xml.stream.XMLOutputFactory
				 * See http://java.sun.com/javase/6/docs/api/javax/xml/stream/XMLOutputFactory.html#newFactory() for more information
				 */
				outputFactory = XMLOutputFactory.newInstance();
			}
		}

		return outputFactory.createXMLStreamWriter(domResult);
	}

	private static Node createDescriptionAbout(Node rdf, String subject) throws XMLStreamException {
		DOMResult domResult = new DOMResult(rdf);

		XMLStreamWriter xmlw = createXMLStreamWriter(domResult);
		xmlw.writeStartElement(RDF_PREFIX, "Description", RDF_URI);
		xmlw.writeAttribute(RDF_PREFIX, RDF_URI, "about", subject);
		xmlw.writeEndElement();
		xmlw.close();

		return RDFReader.findDescriptionAbout(rdf, subject);
	}



	private static void createAnnotation(PieceOfKnowledge annotation, URI subject, String prefix, String namespace, String property, Object value, String lang) throws Exception {

		DocumentBuilderFactory documentBuilderFactory = DocumentBuilderFactory.newInstance();
		DocumentBuilder builder = documentBuilderFactory.newDocumentBuilder();
		Document document = builder.newDocument();
		DOMResult domResult = new DOMResult(document);

		XMLStreamWriter xmlw = createXMLStreamWriter(domResult);

		// Add prefixes
		xmlw.writeStartElement("data");
		xmlw.writeStartElement(RDF_PREFIX, "RDF", RDF_URI);
		xmlw.writeNamespace(RDF_PREFIX, RDF_URI);
		xmlw.writeNamespace(prefix, namespace);
		xmlw.writeStartElement(RDF_PREFIX, "Description", RDF_URI);
		xmlw.writeNamespace(prefix, namespace);
		xmlw.writeAttribute(RDF_PREFIX, RDF_URI, "about", subject.toString());

		// Add annotation
		writeAnnotation(xmlw, prefix, namespace, property, value, lang);

		xmlw.writeEndElement();

		xmlw.writeCharacters("\n");
		xmlw.writeCharacters("        ");
		xmlw.writeEndElement();
		xmlw.writeEndElement();
		xmlw.writeEndDocument();
		xmlw.close();

		annotation.setData(document.getDocumentElement());

	}

	private static void writeAnnotation(XMLStreamWriter xmlw, String prefix, String namespace, String property, Object value, String lang) throws XMLStreamException {

		// Check of properties
		if (property.indexOf(":") != -1 && property.indexOf("/") != -1) {
			int l = property.lastIndexOf('/');
			int d = property.lastIndexOf('#');
			d = d == -1 ? l : d;
			namespace = property.substring(0, d + 1);
			prefix = "w" + namespace.hashCode();
			property = property.substring(d + 1);
		}

		xmlw.writeNamespace(prefix, namespace);
		if (value instanceof URI) {
			writeResource(xmlw, prefix, namespace, property, value.toString(), lang);
		} else {
			writeLiteral(xmlw, prefix, namespace, property, value.toString(), lang);
		}
	}

	private static void writeResource(XMLStreamWriter xmlw, String prefix, String namespace, String property, String value, String lang) throws XMLStreamException {
		xmlw.writeStartElement(prefix, property, namespace);
		xmlw.writeAttribute(RDF_PREFIX, RDF_URI, "resource", value.toString());
		if (lang != null) {
			xmlw.writeAttribute("xml:lang", lang);
		}
		xmlw.writeEndElement();
	}

	private static void writeLiteral(XMLStreamWriter xmlw, String prefix, String namespace, String property, String value, String lang) throws XMLStreamException {
		xmlw.writeStartElement(prefix, property, namespace);
		if (lang != null) {
			xmlw.writeAttribute("xml:lang", lang);
		}
		xmlw.writeCharacters(value.toString());
		xmlw.writeEndElement();
	}

}
