package org.purl.dc.terms;

/**
 * WEBLAB: Service oriented integration platform for media mining and intelligence applications
 * 
 * Copyright (C) 2004 - 2010 CASSIDIAN
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301 USA
 * 
 * /!\ At the time of the 1.2 release, this module is still experimental and need more in 
 * depth use and validation. Use it at your own risks ;-)
 */

import java.net.URI;
import java.util.Date;

import org.ow2.weblab.core.annotator.BaseAnnotator;
import org.ow2.weblab.core.model.PieceOfKnowledge;
import org.ow2.weblab.core.model.Resource;
import org.ow2.weblab.rdf.Value;
import org.ow2.weblab.rdf.XMLParser;

 /**
  * 
  */
public class DCTermsAnnotator extends BaseAnnotator {

	protected static final String PREFIX = "dct";
	protected static final URI URI = XMLParser.buildURI("http://purl.org/dc/terms/");

	public DCTermsAnnotator(URI subject, PieceOfKnowledge pieceOfKnowledge){
		super(subject,pieceOfKnowledge);
	}

	public DCTermsAnnotator(Resource resource){
		super(resource);
	}

	/**
	 * Read the title
	 * 
	 * @return a String
	 */
	public Value<String> readTitle(){
		return applyOperator(Operator.READ, null,URI, TITLE, String.class, null);
	}


	/**
	 * Write the title
	 * @param value a String
	 * @return a boolean
	 */
	public void writeTitle(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, TITLE, String.class, value);
	}


	/**
	 * Read the An entity primarily responsible for making the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readCreator(){
		return applyOperator(Operator.READ, null,URI, CREATOR, URI.class, null);
	}


	/**
	 * Write the An entity primarily responsible for making the resource.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeCreator(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, CREATOR, URI.class, value);
	}


	/**
	 * Read the The topic of the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readSubject(){
		return applyOperator(Operator.READ, null,URI, SUBJECT, String.class, null);
	}


	/**
	 * Write the The topic of the resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeSubject(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, SUBJECT, String.class, value);
	}


	/**
	 * Read the An account of the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readDescription(){
		return applyOperator(Operator.READ, null,URI, DESCRIPTION, String.class, null);
	}


	/**
	 * Write the An account of the resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeDescription(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, DESCRIPTION, String.class, value);
	}


	/**
	 * Read the An entity responsible for making the resource available. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readPublisher(){
		return applyOperator(Operator.READ, null,URI, PUBLISHER, URI.class, null);
	}


	/**
	 * Write the An entity responsible for making the resource available.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writePublisher(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, PUBLISHER, URI.class, value);
	}


	/**
	 * Read the An entity responsible for making contributions to the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readContributor(){
		return applyOperator(Operator.READ, null,URI, CONTRIBUTOR, URI.class, null);
	}


	/**
	 * Write the An entity responsible for making contributions to the resource.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeContributor(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, CONTRIBUTOR, URI.class, value);
	}


	/**
	 * Read the A point or period of time associated with an event in the lifecycle of the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readDate(){
		return applyOperator(Operator.READ, null,URI, DATE, String.class, null);
	}


	/**
	 * Write the A point or period of time associated with an event in the lifecycle of the resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeDate(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, DATE, String.class, value);
	}


	/**
	 * Read the The nature or genre of the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readType(){
		return applyOperator(Operator.READ, null,URI, TYPE, URI.class, null);
	}


	/**
	 * Write the The nature or genre of the resource.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeType(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, TYPE, URI.class, value);
	}


	/**
	 * Read the The file format, physical medium, or dimensions of the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readFormat(){
		return applyOperator(Operator.READ, null,URI, FORMAT, URI.class, null);
	}


	/**
	 * Write the The file format, physical medium, or dimensions of the resource.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeFormat(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, FORMAT, URI.class, value);
	}


	/**
	 * Read the An unambiguous reference to the resource within a given context. 
	 * 
	 * @return a String
	 */
	public Value<String> readIdentifier(){
		return applyOperator(Operator.READ, null,URI, IDENTIFIER, String.class, null);
	}


	/**
	 * Write the An unambiguous reference to the resource within a given context.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeIdentifier(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, IDENTIFIER, String.class, value);
	}


	/**
	 * Read the A related resource from which the described resource is derived. 
	 * 
	 * @return a String
	 */
	public Value<String> readSource(){
		return applyOperator(Operator.READ, null,URI, SOURCE, String.class, null);
	}


	/**
	 * Write the A related resource from which the described resource is derived.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeSource(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, SOURCE, String.class, value);
	}


	/**
	 * Read the A language of the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readLanguage(){
		return applyOperator(Operator.READ, null,URI, LANGUAGE, URI.class, null);
	}


	/**
	 * Write the A language of the resource.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeLanguage(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, LANGUAGE, URI.class, value);
	}


	/**
	 * Read the A related resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readRelation(){
		return applyOperator(Operator.READ, null,URI, RELATION, String.class, null);
	}


	/**
	 * Write the A related resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeRelation(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, RELATION, String.class, value);
	}


	/**
	 * Read the The spatial or temporal topic of the resource, the spatial applicability of the resource, or the jurisdiction under which the resource is relevant. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readCoverage(){
		return applyOperator(Operator.READ, null,URI, COVERAGE, URI.class, null);
	}


	/**
	 * Write the The spatial or temporal topic of the resource, the spatial applicability of the resource, or the jurisdiction under which the resource is relevant.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeCoverage(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, COVERAGE, URI.class, value);
	}


	/**
	 * Read the Information about rights held in and over the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readRights(){
		return applyOperator(Operator.READ, null,URI, RIGHTS, URI.class, null);
	}


	/**
	 * Write the Information about rights held in and over the resource.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeRights(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, RIGHTS, URI.class, value);
	}


	/**
	 * Read the A class of entity for whom the resource is intended or useful. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readAudience(){
		return applyOperator(Operator.READ, null,URI, AUDIENCE, URI.class, null);
	}


	/**
	 * Write the A class of entity for whom the resource is intended or useful.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeAudience(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, AUDIENCE, URI.class, value);
	}


	/**
	 * Read the An alternative name for the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readAlternative(){
		return applyOperator(Operator.READ, null,URI, ALTERNATIVE, String.class, null);
	}


	/**
	 * Write the An alternative name for the resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeAlternative(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, ALTERNATIVE, String.class, value);
	}


	/**
	 * Read the A list of subunits of the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readTableOfContents(){
		return applyOperator(Operator.READ, null,URI, TABLE_OF_CONTENTS, String.class, null);
	}


	/**
	 * Write the A list of subunits of the resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeTableOfContents(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, TABLE_OF_CONTENTS, String.class, value);
	}


	/**
	 * Read the A summary of the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readAbstract(){
		return applyOperator(Operator.READ, null,URI, ABSTRACT, String.class, null);
	}


	/**
	 * Write the A summary of the resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeAbstract(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, ABSTRACT, String.class, value);
	}


	/**
	 * Read the Date of creation of the resource. 
	 * 
	 * @return a Date
	 */
	public Value<Date> readCreated(){
		return applyOperator(Operator.READ, null,URI, CREATED, Date.class, null);
	}


	/**
	 * Write the Date of creation of the resource.
	 * @param value a Date
	 * @return a boolean
	 */
	public void writeCreated(Date value){
		applyOperator(Operator.WRITE, PREFIX,URI, CREATED, Date.class, value);
	}


	/**
	 * Read the Date (often a range) of validity of a resource. 
	 * 
	 * @return a Date
	 */
	public Value<Date> readValid(){
		return applyOperator(Operator.READ, null,URI, VALID, Date.class, null);
	}


	/**
	 * Write the Date (often a range) of validity of a resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeValid(Date value){
		applyOperator(Operator.WRITE, PREFIX,URI, VALID, Date.class, value);
	}


	/**
	 * Read the Date (often a range) that the resource became or will become available. 
	 * 
	 * @return a Date
	 */
	public Value<Date> readAvailable(){
		return applyOperator(Operator.READ, null,URI, AVAILABLE, Date.class, null);
	}


	/**
	 * Write the Date (often a range) that the resource became or will become available.
	 * @param value a Date
	 * @return a boolean
	 */
	public void writeAvailable(Date value){
		applyOperator(Operator.WRITE, PREFIX,URI, AVAILABLE, Date.class, value);
	}


	/**
	 * Read the Date of formal issuance (e.g., publication) of the resource. 
	 * 
	 * @return a Date
	 */
	public Value<Date> readSued(){
		return applyOperator(Operator.READ, null,URI, ISSUED, Date.class, null);
	}


	/**
	 * Write the Date of formal issuance (e.g., publication) of the resource.
	 * @param value a Date
	 * @return a boolean
	 */
	public void writeSued(Date value){
		applyOperator(Operator.WRITE, PREFIX,URI, ISSUED, Date.class, value);
	}


	/**
	 * Read the Date on which the resource was changed. 
	 * 
	 * @return a Date
	 */
	public Value<Date> readModified(){
		return applyOperator(Operator.READ, null,URI, MODIFIED, Date.class, null);
	}


	/**
	 * Write the Date on which the resource was changed.
	 * @param value a Date
	 * @return a boolean
	 */
	public void writeModified(Date value){
		applyOperator(Operator.WRITE, PREFIX,URI, MODIFIED, Date.class, value);
	}


	/**
	 * Read the The size or duration of the resource. 
	 * 
	 * @return an Long
	 */
	public Value<Long> readExtent(){
		return applyOperator(Operator.READ, null,URI, EXTENT, Long.class, null);
	}


	/**
	 * Write the The size or duration of the resource.
	 * @param value an Long
	 * @return a boolean
	 */
	public void writeExtent(Long value){
		applyOperator(Operator.WRITE, PREFIX,URI, EXTENT, Long.class, value);
	}


	/**
	 * Read the The material or physical carrier of the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readMedium(){
		return applyOperator(Operator.READ, null,URI, MEDIUM, URI.class, null);
	}


	/**
	 * Write the The material or physical carrier of the resource.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeMedium(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, MEDIUM, URI.class, value);
	}


	/**
	 * Read the A related resource of which the described resource is a version, edition, or adaptation. 
	 * 
	 * @return a String
	 */
	public Value<String> readVersionOf(){
		return applyOperator(Operator.READ, null,URI, IS_VERSION_OF, String.class, null);
	}


	/**
	 * Write the A related resource of which the described resource is a version, edition, or adaptation.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeVersionOf(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, IS_VERSION_OF, String.class, value);
	}


	/**
	 * Read the A related resource that is a version, edition, or adaptation of the described resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readVersion(){
		return applyOperator(Operator.READ, null,URI, HAS_VERSION, String.class, null);
	}


	/**
	 * Write the A related resource that is a version, edition, or adaptation of the described resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeVersion(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, HAS_VERSION, String.class, value);
	}


	/**
	 * Read the A related resource that supplants, displaces, or supersedes the described resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readReplacedBy(){
		return applyOperator(Operator.READ, null,URI, IS_REPLACED_BY, String.class, null);
	}


	/**
	 * Write the A related resource that supplants, displaces, or supersedes the described resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeReplacedBy(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, IS_REPLACED_BY, String.class, value);
	}


	/**
	 * Read the A related resource that is supplanted, displaced, or superseded by the described resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readReplaces(){
		return applyOperator(Operator.READ, null,URI, REPLACES, String.class, null);
	}


	/**
	 * Write the A related resource that is supplanted, displaced, or superseded by the described resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeReplaces(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, REPLACES, String.class, value);
	}


	/**
	 * Read the A related resource that requires the described resource to support its function, delivery, or coherence. 
	 * 
	 * @return a String
	 */
	public Value<String> readRequiredBy(){
		return applyOperator(Operator.READ, null,URI, IS_REQUIRED_BY, String.class, null);
	}


	/**
	 * Write the A related resource that requires the described resource to support its function, delivery, or coherence.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeRequiredBy(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, IS_REQUIRED_BY, String.class, value);
	}


	/**
	 * Read the A related resource that is required by the described resource to support its function, delivery, or coherence. 
	 * 
	 * @return a String
	 */
	public Value<String> readRequires(){
		return applyOperator(Operator.READ, null,URI, REQUIRES, String.class, null);
	}


	/**
	 * Write the A related resource that is required by the described resource to support its function, delivery, or coherence.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeRequires(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, REQUIRES, String.class, value);
	}


	/**
	 * Read the A related resource in which the described resource is physically or logically included. 
	 * 
	 * @return a String
	 */
	public Value<String> readPartOf(){
		return applyOperator(Operator.READ, null,URI, IS_PART_OF, String.class, null);
	}


	/**
	 * Write the A related resource in which the described resource is physically or logically included.
	 * @param value a String
	 * @return a boolean
	 */
	public void writePartOf(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, IS_PART_OF, String.class, value);
	}


	/**
	 * Read the A related resource that is included either physically or logically in the described resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readPart(){
		return applyOperator(Operator.READ, null,URI, HAS_PART, String.class, null);
	}


	/**
	 * Write the A related resource that is included either physically or logically in the described resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writePart(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, HAS_PART, String.class, value);
	}


	/**
	 * Read the A related resource that references, cites, or otherwise points to the described resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readReferencedBy(){
		return applyOperator(Operator.READ, null,URI, IS_REFERENCED_BY, String.class, null);
	}


	/**
	 * Write the A related resource that references, cites, or otherwise points to the described resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeReferencedBy(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, IS_REFERENCED_BY, String.class, value);
	}


	/**
	 * Read the A related resource that is referenced, cited, or otherwise pointed to by the described resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readReferences(){
		return applyOperator(Operator.READ, null,URI, REFERENCES, String.class, null);
	}


	/**
	 * Write the A related resource that is referenced, cited, or otherwise pointed to by the described resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeReferences(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, REFERENCES, String.class, value);
	}


	/**
	 * Read the A related resource that is substantially the same as the described resource, but in another format. 
	 * 
	 * @return a String
	 */
	public Value<String> readFormatOf(){
		return applyOperator(Operator.READ, null,URI, IS_FORMAT_OF, String.class, null);
	}


	/**
	 * Write the A related resource that is substantially the same as the described resource, but in another format.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeFormatOf(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, IS_FORMAT_OF, String.class, value);
	}


	/**
	 * Read the A related resource that is substantially the same as the pre-existing described resource, but in another format. 
	 * 
	 * @return a String
	 */
	public Value<String> readOtherFormat(){
		return applyOperator(Operator.READ, null,URI, HAS_FORMAT, String.class, null);
	}


	/**
	 * Write the A related resource that is substantially the same as the pre-existing described resource, but in another format.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeOtherFormat(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, HAS_FORMAT, String.class, value);
	}


	/**
	 * Read the An established standard to which the described resource conforms. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readConformsTo(){
		return applyOperator(Operator.READ, null,URI, CONFORMS_TO, URI.class, null);
	}


	/**
	 * Write the An established standard to which the described resource conforms.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeConformsTo(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, CONFORMS_TO, URI.class, value);
	}


	/**
	 * Read the Spatial characteristics of the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readSpatial(){
		return applyOperator(Operator.READ, null,URI, SPATIAL, URI.class, null);
	}


	/**
	 * Write the Spatial characteristics of the resource.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeSpatial(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, SPATIAL, URI.class, value);
	}


	/**
	 * Read the Temporal characteristics of the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readTemporal(){
		return applyOperator(Operator.READ, null,URI, TEMPORAL, URI.class, null);
	}


	/**
	 * Write the Temporal characteristics of the resource.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeTemporal(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, TEMPORAL, URI.class, value);
	}


	/**
	 * Read the An entity that mediates access to the resource and for whom the resource is intended or useful. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readMediator(){
		return applyOperator(Operator.READ, null,URI, MEDIATOR, URI.class, null);
	}


	/**
	 * Write the An entity that mediates access to the resource and for whom the resource is intended or useful.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeMediator(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, MEDIATOR, URI.class, value);
	}


	/**
	 * Read the Date of acceptance of the resource. 
	 * 
	 * @return a Date
	 */
	public Value<Date> readDateAccepted(){
		return applyOperator(Operator.READ, null,URI, DATE_ACCEPTED, Date.class, null);
	}


	/**
	 * Write the Date of acceptance of the resource.
	 * @param value a Date
	 * @return a boolean
	 */
	public void writeDateAccepted(Date value){
		applyOperator(Operator.WRITE, PREFIX,URI, DATE_ACCEPTED, Date.class, value);
	}


	/**
	 * Read the Date of copyright. 
	 * 
	 * @return a Date
	 */
	public Value<Date> readDateCopyrighted(){
		return applyOperator(Operator.READ, null,URI, DATE_COPYRIGHTED, Date.class, null);
	}


	/**
	 * Write the Date of copyright.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeDateCopyrighted(Date value){
		applyOperator(Operator.WRITE, PREFIX,URI, DATE_COPYRIGHTED, Date.class, value);
	}


	/**
	 * Read the Date of submission of the resource. 
	 * 
	 * @return a Date
	 */
	public Value<Date> readDateSubmitted(){
		return applyOperator(Operator.READ, null,URI, DATE_SUBMITTED, Date.class, null);
	}


	/**
	 * Write the Date of submission of the resource.
	 * @param value a Date
	 * @return a boolean
	 */
	public void writeDateSubmitted(Date value){
		applyOperator(Operator.WRITE, PREFIX,URI, DATE_SUBMITTED, Date.class, value);
	}


	/**
	 * Read the A class of entity, defined in terms of progression through an educational or training context, for which the described resource is intended. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readEducationLevel(){
		return applyOperator(Operator.READ, null,URI, EDUCATION_LEVEL, URI.class, null);
	}


	/**
	 * Write the A class of entity, defined in terms of progression through an educational or training context, for which the described resource is intended.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeEducationLevel(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, EDUCATION_LEVEL, URI.class, value);
	}


	/**
	 * Read the Information about who can access the resource or an indication of its security status. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readAccessRights(){
		return applyOperator(Operator.READ, null,URI, ACCESS_RIGHTS, URI.class, null);
	}


	/**
	 * Write the Information about who can access the resource or an indication of its security status.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeAccessRights(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, ACCESS_RIGHTS, URI.class, value);
	}


	/**
	 * Read the A bibliographic reference for the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readBibliographicCitation(){
		return applyOperator(Operator.READ, null,URI, BIBLIOGRAPHIC_CITATION, String.class, null);
	}


	/**
	 * Write the A bibliographic reference for the resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeBibliographicCitation(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, BIBLIOGRAPHIC_CITATION, String.class, value);
	}


	/**
	 * Read the A legal document giving official permission to do something with the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readLicense(){
		return applyOperator(Operator.READ, null,URI, LICENSE, URI.class, null);
	}


	/**
	 * Write the A legal document giving official permission to do something with the resource.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeLicense(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, LICENSE, URI.class, value);
	}


	/**
	 * Read the A person or organization owning or managing rights over the resource. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readRightsHolder(){
		return applyOperator(Operator.READ, null,URI, RIGHTS_HOLDER, URI.class, null);
	}


	/**
	 * Write the A person or organization owning or managing rights over the resource.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeRightsHolder(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, RIGHTS_HOLDER, URI.class, value);
	}


	/**
	 * Read the A statement of any changes in ownership and custody of the resource since its creation that are significant for its authenticity, integrity, and interpretation. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readProvenance(){
		return applyOperator(Operator.READ, null,URI, PROVENANCE, URI.class, null);
	}


	/**
	 * Write the A statement of any changes in ownership and custody of the resource since its creation that are significant for its authenticity, integrity, and interpretation.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeProvenance(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, PROVENANCE, URI.class, value);
	}


	/**
	 * Read the A process, used to engender knowledge, attitudes and skills, that the described resource is designed to support. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readInstructionalMethod(){
		return applyOperator(Operator.READ, null,URI, INSTRUCTIONAL_METHOD, URI.class, null);
	}


	/**
	 * Write the A process, used to engender knowledge, attitudes and skills, that the described resource is designed to support.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeInstructionalMethod(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, INSTRUCTIONAL_METHOD, URI.class, value);
	}


	/**
	 * Read the The method by which items are added to a collection. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readAccrualMethod(){
		return applyOperator(Operator.READ, null,URI, ACCRUAL_METHOD, URI.class, null);
	}


	/**
	 * Write the The method by which items are added to a collection.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeAccrualMethod(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, ACCRUAL_METHOD, URI.class, value);
	}


	/**
	 * Read the The frequency with which items are added to a collection. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readAccrualPeriodicity(){
		return applyOperator(Operator.READ, null,URI, ACCRUAL_PERIODICITY, URI.class, null);
	}


	/**
	 * Write the The frequency with which items are added to a collection.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeAccrualPeriodicity(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, ACCRUAL_PERIODICITY, URI.class, value);
	}


	/**
	 * Read the The policy governing the addition of items to a collection. 
	 * 
	 * @return an URI
	 */
	public Value<URI> readAccrualPolicy(){
		return applyOperator(Operator.READ, null,URI, ACCRUAL_POLICY, URI.class, null);
	}


	/**
	 * Write the The policy governing the addition of items to a collection.
	 * @param value an URI
	 * @return a boolean
	 */
	public void writeAccrualPolicy(URI value){
		applyOperator(Operator.WRITE, PREFIX,URI, ACCRUAL_POLICY, URI.class, value);
	}


	/**
	 * Read the A resource that acts or has the power to act. 
	 * 
	 * @return a String
	 */
	public Value<String> readAgent(){
		return applyOperator(Operator.READ, null,URI, _AGENT, String.class, null);
	}


	/**
	 * Write the A resource that acts or has the power to act.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeAgent(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _AGENT, String.class, value);
	}


	/**
	 * Read the A group of agents. 
	 * 
	 * @return a String
	 */
	public Value<String> readAgentClass(){
		return applyOperator(Operator.READ, null,URI, _AGENT_CLASS, String.class, null);
	}


	/**
	 * Write the A group of agents.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeAgentClass(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _AGENT_CLASS, String.class, value);
	}


	/**
	 * Read the A book, article, or other documentary resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readBibliographicResource(){
		return applyOperator(Operator.READ, null,URI, _BIBLIOGRAPHIC_RESOURCE, String.class, null);
	}


	/**
	 * Write the A book, article, or other documentary resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeBibliographicResource(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _BIBLIOGRAPHIC_RESOURCE, String.class, value);
	}


	/**
	 * Read the A digital resource format. 
	 * 
	 * @return a String
	 */
	public Value<String> readFileFormat(){
		return applyOperator(Operator.READ, null,URI, _FILE_FORMAT, String.class, null);
	}


	/**
	 * Write the A digital resource format.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeFileFormat(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _FILE_FORMAT, String.class, value);
	}


	/**
	 * Read the A rate at which something recurs. 
	 * 
	 * @return a String
	 */
	public Value<String> readFrequency(){
		return applyOperator(Operator.READ, null,URI, _FREQUENCY, String.class, null);
	}


	/**
	 * Write the A rate at which something recurs.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeFrequency(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _FREQUENCY, String.class, value);
	}


	/**
	 * Read the The extent or range of judicial, law enforcement, or other authority. 
	 * 
	 * @return a String
	 */
	public Value<String> readJurisdiction(){
		return applyOperator(Operator.READ, null,URI, _JURISDICTION, String.class, null);
	}


	/**
	 * Write the The extent or range of judicial, law enforcement, or other authority.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeJurisdiction(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _JURISDICTION, String.class, value);
	}


	/**
	 * Read the A legal document giving official permission to do something with a Resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readLicenseDocument(){
		return applyOperator(Operator.READ, null,URI, _LICENSE_DOCUMENT, String.class, null);
	}


	/**
	 * Write the A legal document giving official permission to do something with a Resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeLicenseDocument(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _LICENSE_DOCUMENT, String.class, value);
	}


	/**
	 * Read the A system of signs, symbols, sounds, gestures, or rules used in communication. 
	 * 
	 * @return a String
	 */
	public Value<String> readLinguisticSystem(){
		return applyOperator(Operator.READ, null,URI, _LINGUISTIC_SYSTEM, String.class, null);
	}


	/**
	 * Write the A system of signs, symbols, sounds, gestures, or rules used in communication.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeLinguisticSystem(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _LINGUISTIC_SYSTEM, String.class, value);
	}


	/**
	 * Read the A spatial region or named place. 
	 * 
	 * @return a String
	 */
	public Value<String> readLocation(){
		return applyOperator(Operator.READ, null,URI, _LOCATION, String.class, null);
	}


	/**
	 * Write the A spatial region or named place.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeLocation(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _LOCATION, String.class, value);
	}


	/**
	 * Read the A location, period of time, or jurisdiction. 
	 * 
	 * @return a String
	 */
	public Value<String> readLocationPeriodOrJurisdiction(){
		return applyOperator(Operator.READ, null,URI, _LOCATION_PERIOD_OR_JURISDICTION, String.class, null);
	}


	/**
	 * Write the A location, period of time, or jurisdiction.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeLocationPeriodOrJurisdiction(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _LOCATION_PERIOD_OR_JURISDICTION, String.class, value);
	}


	/**
	 * Read the A file format or physical medium. 
	 * 
	 * @return a String
	 */
	public Value<String> readMediaType(){
		return applyOperator(Operator.READ, null,URI, _MEDIA_TYPE, String.class, null);
	}


	/**
	 * Write the A file format or physical medium.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeMediaType(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _MEDIA_TYPE, String.class, value);
	}


	/**
	 * Read the A media type or extent. 
	 * 
	 * @return a String
	 */
	public Value<String> readMediaTypeOrExtent(){
		return applyOperator(Operator.READ, null,URI, _MEDIA_TYPE_OR_EXTENT, String.class, null);
	}


	/**
	 * Write the A media type or extent.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeMediaTypeOrExtent(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _MEDIA_TYPE_OR_EXTENT, String.class, value);
	}


	/**
	 * Read the A process that is used to engender knowledge, attitudes, and skills. 
	 * 
	 * @return a String
	 */
	public Value<String> readMethodOfInstruction(){
		return applyOperator(Operator.READ, null,URI, _METHOD_OF_INSTRUCTION, String.class, null);
	}


	/**
	 * Write the A process that is used to engender knowledge, attitudes, and skills.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeMethodOfInstruction(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _METHOD_OF_INSTRUCTION, String.class, value);
	}


	/**
	 * Read the A method by which resources are added to a collection. 
	 * 
	 * @return a String
	 */
	public Value<String> readMethodOfAccrual(){
		return applyOperator(Operator.READ, null,URI, _METHOD_OF_ACCRUAL, String.class, null);
	}


	/**
	 * Write the A method by which resources are added to a collection.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeMethodOfAccrual(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _METHOD_OF_ACCRUAL, String.class, value);
	}


	/**
	 * Read the An interval of time that is named or defined by its start and end dates. 
	 * 
	 * @return a String
	 */
	public Value<String> readPeriodOfTime(){
		return applyOperator(Operator.READ, null,URI, _PERIOD_OF_TIME, String.class, null);
	}


	/**
	 * Write the An interval of time that is named or defined by its start and end dates.
	 * @param value a String
	 * @return a boolean
	 */
	public void writePeriodOfTime(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _PERIOD_OF_TIME, String.class, value);
	}


	/**
	 * Read the A physical material or carrier. 
	 * 
	 * @return a String
	 */
	public Value<String> readPhysicalMedium(){
		return applyOperator(Operator.READ, null,URI, _PHYSICAL_MEDIUM, String.class, null);
	}


	/**
	 * Write the A physical material or carrier.
	 * @param value a String
	 * @return a boolean
	 */
	public void writePhysicalMedium(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _PHYSICAL_MEDIUM, String.class, value);
	}


	/**
	 * Read the A material thing. 
	 * 
	 * @return a String
	 */
	public Value<String> readPhysicalResource(){
		return applyOperator(Operator.READ, null,URI, _PHYSICAL_RESOURCE, String.class, null);
	}


	/**
	 * Write the A material thing.
	 * @param value a String
	 * @return a boolean
	 */
	public void writePhysicalResource(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _PHYSICAL_RESOURCE, String.class, value);
	}


	/**
	 * Read the A plan or course of action by an authority, intended to influence and determine decisions, actions, and other matters. 
	 * 
	 * @return a String
	 */
	public Value<String> readPolicy(){
		return applyOperator(Operator.READ, null,URI, _POLICY, String.class, null);
	}


	/**
	 * Write the A plan or course of action by an authority, intended to influence and determine decisions, actions, and other matters.
	 * @param value a String
	 * @return a boolean
	 */
	public void writePolicy(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _POLICY, String.class, value);
	}


	/**
	 * Read the A statement of any changes in ownership and custody of a resource since its creation that are significant for its authenticity, integrity, and interpretation. 
	 * 
	 * @return a String
	 */
	public Value<String> readProvenanceStatement(){
		return applyOperator(Operator.READ, null,URI, _PROVENANCE_STATEMENT, String.class, null);
	}


	/**
	 * Write the A statement of any changes in ownership and custody of a resource since its creation that are significant for its authenticity, integrity, and interpretation.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeProvenanceStatement(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _PROVENANCE_STATEMENT, String.class, value);
	}


	/**
	 * Read the A statement about the intellectual property rights (IPR) held in or over a Resource, a legal document giving official permission to do something with a resource, or a statement about access rights. 
	 * 
	 * @return a String
	 */
	public Value<String> readRightsStatement(){
		return applyOperator(Operator.READ, null,URI, _RIGHTS_STATEMENT, String.class, null);
	}


	/**
	 * Write the A statement about the intellectual property rights (IPR) held in or over a Resource, a legal document giving official permission to do something with a resource, or a statement about access rights.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeRightsStatement(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _RIGHTS_STATEMENT, String.class, value);
	}


	/**
	 * Read the A dimension or extent, or a time taken to play or execute. 
	 * 
	 * @return a Long
	 */
	public Value<Long> readSizeOrDuration(){
		return applyOperator(Operator.READ, null,URI, _SIZE_OR_DURATION, Long.class, null);
	}


	/**
	 * Write the A dimension or extent, or a time taken to play or execute.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeSizeOrDuration(Long value){
		applyOperator(Operator.WRITE, PREFIX,URI, _SIZE_OR_DURATION, Long.class, value);
	}


	/**
	 * Read the A basis for comparison; a reference point against which other things can be evaluated. 
	 * 
	 * @return a String
	 */
	public Value<String> readStandard(){
		return applyOperator(Operator.READ, null,URI, _STANDARD, String.class, null);
	}


	/**
	 * Write the A basis for comparison; a reference point against which other things can be evaluated.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeStandard(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _STANDARD, String.class, value);
	}


	/**
	 * Read the The three-letter alphabetic codes listed in ISO639-2 for the representation of names of languages. 
	 * 
	 * @return a String
	 */
	public Value<String> readISO639_2(){
		return applyOperator(Operator.READ, null,URI, _I_S_O639_2, String.class, null);
	}


	/**
	 * Write the The three-letter alphabetic codes listed in ISO639-2 for the representation of names of languages.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeISO639_2(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _I_S_O639_2, String.class, value);
	}


	/**
	 * Read the The set of tags, constructed according to RFC 1766, for the identification of languages. 
	 * 
	 * @return a String
	 */
	public Value<String> readRFC1766(){
		return applyOperator(Operator.READ, null,URI, _R_F_C1766, String.class, null);
	}


	/**
	 * Write the The set of tags, constructed according to RFC 1766, for the identification of languages.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeRFC1766(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _R_F_C1766, String.class, value);
	}


	/**
	 * Read the The set of identifiers constructed according to the generic syntax for Uniform Resource Identifiers as specified by the Internet Engineering Task Force. 
	 * 
	 * @return a String
	 */
	public Value<String> readURI(){
		return applyOperator(Operator.READ, null,URI, _U_R_I, String.class, null);
	}


	/**
	 * Write the The set of identifiers constructed according to the generic syntax for Uniform Resource Identifiers as specified by the Internet Engineering Task Force.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeURI(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _U_R_I, String.class, value);
	}


	/**
	 * Read the The set of points in space defined by their geographic coordinates according to the DCMI Point Encoding Scheme. 
	 * 
	 * @return a String
	 */
	public Value<String> readPoint(){
		return applyOperator(Operator.READ, null,URI, _POINT, String.class, null);
	}


	/**
	 * Write the The set of points in space defined by their geographic coordinates according to the DCMI Point Encoding Scheme.
	 * @param value a String
	 * @return a boolean
	 */
	public void writePoint(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _POINT, String.class, value);
	}


	/**
	 * Read the The set of codes listed in ISO 3166-1 for the representation of names of countries. 
	 * 
	 * @return a String
	 */
	public Value<String> readISO3166(){
		return applyOperator(Operator.READ, null,URI, _I_S_O3166, String.class, null);
	}


	/**
	 * Write the The set of codes listed in ISO 3166-1 for the representation of names of countries.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeISO3166(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _I_S_O3166, String.class, value);
	}


	/**
	 * Read the The set of regions in space defined by their geographic coordinates according to the DCMI Box Encoding Scheme. 
	 * 
	 * @return a String
	 */
	public Value<String> readBox(){
		return applyOperator(Operator.READ, null,URI, _BOX, String.class, null);
	}


	/**
	 * Write the The set of regions in space defined by their geographic coordinates according to the DCMI Box Encoding Scheme.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeBox(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _BOX, String.class, value);
	}


	/**
	 * Read the The set of time intervals defined by their limits according to the DCMI Period Encoding Scheme. 
	 * 
	 * @return a String
	 */
	public Value<String> readPeriod(){
		return applyOperator(Operator.READ, null,URI, _PERIOD, String.class, null);
	}


	/**
	 * Write the The set of time intervals defined by their limits according to the DCMI Period Encoding Scheme.
	 * @param value a String
	 * @return a boolean
	 */
	public void writePeriod(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _PERIOD, String.class, value);
	}


	/**
	 * Read the The set of dates and times constructed according to the W3C Date and Time Formats Specification. 
	 * 
	 * @return a String
	 */
	public Value<Date> readW3CDTF(){
		return applyOperator(Operator.READ, null,URI, _W3_C_D_T_F, Date.class, null);
	}


	/**
	 * Write the The set of dates and times constructed according to the W3C Date and Time Formats Specification.
	 * @param value a Date
	 * @return a boolean
	 */
	public void writeW3CDTF(Date value){
		applyOperator(Operator.WRITE, PREFIX,URI, _W3_C_D_T_F, Date.class, value);
	}


	/**
	 * Read the The set of tags constructed according to RFC 3066 for the identification of languages. 
	 * 
	 * @return a String
	 */
	public Value<String> readRFC3066(){
		return applyOperator(Operator.READ, null,URI, _R_F_C3066, String.class, null);
	}


	/**
	 * Write the The set of tags constructed according to RFC 3066 for the identification of languages.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeRFC3066(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _R_F_C3066, String.class, value);
	}


	/**
	 * Read the The set of tags constructed according to RFC 4646 for the identification of languages. 
	 * 
	 * @return a String
	 */
	public Value<String> readRFC4646(){
		return applyOperator(Operator.READ, null,URI, _R_F_C4646, String.class, null);
	}


	/**
	 * Write the The set of tags constructed according to RFC 4646 for the identification of languages.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeRFC4646(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _R_F_C4646, String.class, value);
	}


	/**
	 * Read the The set of three-letter codes listed in ISO 639-3 for the representation of names of languages. 
	 * 
	 * @return a String
	 */
	public Value<String> readISO639_3(){
		return applyOperator(Operator.READ, null,URI, _I_S_O639_3, String.class, null);
	}


	/**
	 * Write the The set of three-letter codes listed in ISO 639-3 for the representation of names of languages.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeISO639_3(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _I_S_O639_3, String.class, value);
	}


	/**
	 * Read the The set of labeled concepts specified by the Library of Congress Subject Headings. 
	 * 
	 * @return a String
	 */
	public Value<String> readLCSH(){
		return applyOperator(Operator.READ, null,URI, _L_C_S_H, String.class, null);
	}


	/**
	 * Write the The set of labeled concepts specified by the Library of Congress Subject Headings.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeLCSH(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _L_C_S_H, String.class, value);
	}


	/**
	 * Read the The set of labeled concepts specified by the Medical Subject Headings. 
	 * 
	 * @return a String
	 */
	public Value<String> readMESH(){
		return applyOperator(Operator.READ, null,URI, _M_E_S_H, String.class, null);
	}


	/**
	 * Write the The set of labeled concepts specified by the Medical Subject Headings.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeMESH(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _M_E_S_H, String.class, value);
	}


	/**
	 * Read the The set of conceptual resources specified by the Dewey Decimal Classification. 
	 * 
	 * @return a String
	 */
	public Value<String> readDDC(){
		return applyOperator(Operator.READ, null,URI, _D_D_C, String.class, null);
	}


	/**
	 * Write the The set of conceptual resources specified by the Dewey Decimal Classification.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeDDC(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _D_D_C, String.class, value);
	}


	/**
	 * Read the The set of conceptual resources specified by the Library of Congress Classification. 
	 * 
	 * @return a String
	 */
	public Value<String> readLCC(){
		return applyOperator(Operator.READ, null,URI, _L_C_C, String.class, null);
	}


	/**
	 * Write the The set of conceptual resources specified by the Library of Congress Classification.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeLCC(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _L_C_C, String.class, value);
	}


	/**
	 * Read the The set of conceptual resources specified by the Universal Decimal Classification. 
	 * 
	 * @return a String
	 */
	public Value<String> readUDC(){
		return applyOperator(Operator.READ, null,URI, _U_D_C, String.class, null);
	}


	/**
	 * Write the The set of conceptual resources specified by the Universal Decimal Classification.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeUDC(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _U_D_C, String.class, value);
	}


	/**
	 * Read the The set of classes specified by the DCMI Type Vocabulary, used to categorize the nature or genre of the resource. 
	 * 
	 * @return a String
	 */
	public Value<String> readDCMIType(){
		return applyOperator(Operator.READ, null,URI, _D_C_M_I_TYPE, String.class, null);
	}


	/**
	 * Write the The set of classes specified by the DCMI Type Vocabulary, used to categorize the nature or genre of the resource.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeDCMIType(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _D_C_M_I_TYPE, String.class, value);
	}


	/**
	 * Read the The set of media types specified by the Internet Assigned Numbers Authority. 
	 * 
	 * @return a String
	 */
	public Value<String> readIMT(){
		return applyOperator(Operator.READ, null,URI, _I_M_T, String.class, null);
	}


	/**
	 * Write the The set of media types specified by the Internet Assigned Numbers Authority.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeIMT(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _I_M_T, String.class, value);
	}


	/**
	 * Read the The set of places specified by the Getty Thesaurus of Geographic Names. 
	 * 
	 * @return a String
	 */
	public Value<String> readTGN(){
		return applyOperator(Operator.READ, null,URI, _T_G_N, String.class, null);
	}


	/**
	 * Write the The set of places specified by the Getty Thesaurus of Geographic Names.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeTGN(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _T_G_N, String.class, value);
	}


	/**
	 * Read the The set of conceptual resources specified by the National Library of Medicine Classification. 
	 * 
	 * @return a String
	 */
	public Value<String> readNLM(){
		return applyOperator(Operator.READ, null,URI, _N_L_M, String.class, null);
	}


	/**
	 * Write the The set of conceptual resources specified by the National Library of Medicine Classification.
	 * @param value a String
	 * @return a boolean
	 */
	public void writeNLM(String value){
		applyOperator(Operator.WRITE, PREFIX,URI, _N_L_M, String.class, value);
	}


	protected static final String TITLE = "title";
	protected static final String CREATOR = "creator";
	protected static final String SUBJECT = "subject";
	protected static final String DESCRIPTION = "description";
	protected static final String PUBLISHER = "publisher";
	protected static final String CONTRIBUTOR = "contributor";
	protected static final String DATE = "date";
	protected static final String TYPE = "type";
	protected static final String FORMAT = "format";
	protected static final String IDENTIFIER = "identifier";
	protected static final String SOURCE = "source";
	protected static final String LANGUAGE = "language";
	protected static final String RELATION = "relation";
	protected static final String COVERAGE = "coverage";
	protected static final String RIGHTS = "rights";
	protected static final String AUDIENCE = "audience";
	protected static final String ALTERNATIVE = "alternative";
	protected static final String TABLE_OF_CONTENTS = "tableOfContents";
	protected static final String ABSTRACT = "abstract";
	protected static final String CREATED = "created";
	protected static final String VALID = "valid";
	protected static final String AVAILABLE = "available";
	protected static final String ISSUED = "issued";
	protected static final String MODIFIED = "modified";
	protected static final String EXTENT = "extent";
	protected static final String MEDIUM = "medium";
	protected static final String IS_VERSION_OF = "isVersionOf";
	protected static final String HAS_VERSION = "hasVersion";
	protected static final String IS_REPLACED_BY = "isReplacedBy";
	protected static final String REPLACES = "replaces";
	protected static final String IS_REQUIRED_BY = "isRequiredBy";
	protected static final String REQUIRES = "requires";
	protected static final String IS_PART_OF = "isPartOf";
	protected static final String HAS_PART = "hasPart";
	protected static final String IS_REFERENCED_BY = "isReferencedBy";
	protected static final String REFERENCES = "references";
	protected static final String IS_FORMAT_OF = "isFormatOf";
	protected static final String HAS_FORMAT = "hasFormat";
	protected static final String CONFORMS_TO = "conformsTo";
	protected static final String SPATIAL = "spatial";
	protected static final String TEMPORAL = "temporal";
	protected static final String MEDIATOR = "mediator";
	protected static final String DATE_ACCEPTED = "dateAccepted";
	protected static final String DATE_COPYRIGHTED = "dateCopyrighted";
	protected static final String DATE_SUBMITTED = "dateSubmitted";
	protected static final String EDUCATION_LEVEL = "educationLevel";
	protected static final String ACCESS_RIGHTS = "accessRights";
	protected static final String BIBLIOGRAPHIC_CITATION = "bibliographicCitation";
	protected static final String LICENSE = "license";
	protected static final String RIGHTS_HOLDER = "rightsHolder";
	protected static final String PROVENANCE = "provenance";
	protected static final String INSTRUCTIONAL_METHOD = "instructionalMethod";
	protected static final String ACCRUAL_METHOD = "accrualMethod";
	protected static final String ACCRUAL_PERIODICITY = "accrualPeriodicity";
	protected static final String ACCRUAL_POLICY = "accrualPolicy";
	protected static final String _AGENT = "Agent";
	protected static final String _AGENT_CLASS = "AgentClass";
	protected static final String _BIBLIOGRAPHIC_RESOURCE = "BibliographicResource";
	protected static final String _FILE_FORMAT = "FileFormat";
	protected static final String _FREQUENCY = "Frequency";
	protected static final String _JURISDICTION = "Jurisdiction";
	protected static final String _LICENSE_DOCUMENT = "LicenseDocument";
	protected static final String _LINGUISTIC_SYSTEM = "LinguisticSystem";
	protected static final String _LOCATION = "Location";
	protected static final String _LOCATION_PERIOD_OR_JURISDICTION = "LocationPeriodOrJurisdiction";
	protected static final String _MEDIA_TYPE = "MediaType";
	protected static final String _MEDIA_TYPE_OR_EXTENT = "MediaTypeOrExtent";
	protected static final String _METHOD_OF_INSTRUCTION = "MethodOfInstruction";
	protected static final String _METHOD_OF_ACCRUAL = "MethodOfAccrual";
	protected static final String _PERIOD_OF_TIME = "PeriodOfTime";
	protected static final String _PHYSICAL_MEDIUM = "PhysicalMedium";
	protected static final String _PHYSICAL_RESOURCE = "PhysicalResource";
	protected static final String _POLICY = "Policy";
	protected static final String _PROVENANCE_STATEMENT = "ProvenanceStatement";
	protected static final String _RIGHTS_STATEMENT = "RightsStatement";
	protected static final String _SIZE_OR_DURATION = "SizeOrDuration";
	protected static final String _STANDARD = "Standard";
	protected static final String _I_S_O639_2 = "ISO639_2";
	protected static final String _R_F_C1766 = "RFC1766";
	protected static final String _U_R_I = "URI";
	protected static final String _POINT = "Point";
	protected static final String _I_S_O3166 = "ISO3166";
	protected static final String _BOX = "Box";
	protected static final String _PERIOD = "Period";
	protected static final String _W3_C_D_T_F = "W3CDTF";
	protected static final String _R_F_C3066 = "RFC3066";
	protected static final String _R_F_C4646 = "RFC4646";
	protected static final String _I_S_O639_3 = "ISO639_3";
	protected static final String _L_C_S_H = "LCSH";
	protected static final String _M_E_S_H = "MESH";
	protected static final String _D_D_C = "DDC";
	protected static final String _L_C_C = "LCC";
	protected static final String _U_D_C = "UDC";
	protected static final String _D_C_M_I_TYPE = "DCMIType";
	protected static final String _I_M_T = "IMT";
	protected static final String _T_G_N = "TGN";
	protected static final String _N_L_M = "NLM";

}

